import React, { FunctionComponent } from 'react';


type ILoadingSpinnerProp = {
    color?: string;
    style?: React.CSSProperties;
}

const LoadingSpinner: FunctionComponent<ILoadingSpinnerProp> = ({ color, style }) => {
    return (
        <>
        <style jsx>{`
            .spinner {
                width: 70px;
                text-align: center;
            }
            
            .spinner > div {
                width: 12px;
                height: 12px;
                background-color: ${ color ?? 'white' };
                border-radius: 100%;
                display: inline-block;
                -webkit-animation: bouncedelay 1.4s infinite ease-in-out both;
                animation: bouncedelay 1.4s infinite ease-in-out both;
            }
            
            .spinner .bounce1 {
                margin-right: 3px;
                -webkit-animation-delay: -0.32s;
                animation-delay: -0.32s;
            }
            
            .spinner .bounce2 {
                margin-right: 3px;
                -webkit-animation-delay: -0.16s;
                animation-delay: -0.16s;
            }
            
            @-webkit-keyframes bouncedelay {
                0%, 80%, 100% { -webkit-transform: scale(0) }
                40% { -webkit-transform: scale(1.0) }
            }
            
            @keyframes bouncedelay {
                0%, 80%, 100% { 
                    -webkit-transform: scale(0); 
                    transform: scale(0); 
                }
                40% { 
                    -webkit-transform: scale(1.0);
                    transform: scale(1.0);
                }
            }
        `}</style>

        <div className="spinner" style={style}>
            <div className="bounce1"></div>
            <div className="bounce2"></div>
            <div className="bounce3"></div>
        </div>
        </>
    )
}

export default LoadingSpinner;