import React, { FunctionComponent } from 'react';

import { LoadingSpinner } from '../containers';
import theme from '../../styles/theme';

type IButtonProp = {
    text: string;
    type?: 'submit' | 'reset' | 'button';
    buttonStyle?: 'positive' | 'neutral' | 'negative';  
    loading?: boolean;
    onClick: (e: React.MouseEvent) => void;
    style?: React.CSSProperties;
}

const Button: FunctionComponent<IButtonProp> = ({ text, type, buttonStyle, style, loading, onClick }) => {
    return (
        <>
        <style jsx>{`
            .button {
                padding: 0;
                margin: 0;
                border: none;
                border-radius: 5px;
                outline: none;
                width: 100%;
                height: 50px;
                font-family: "Poppins", sans-serif;
                font-size: ${theme.fontSizes.button}px;
                color: ${buttonStyle && buttonStyle !== 'neutral' ? 'black' : theme.colors.primary};
                background-color: ${buttonStyle && buttonStyle !== 'neutral' ? (buttonStyle === 'positive' ? theme.colors.success : theme.colors.error) : theme.colors.secondary};
                cursor: pointer;
            }
        `}</style>

        <button className="button" style={style} type={type} onClick={(event) => {if (!loading) onClick(event); else event.preventDefault();}}>
            {loading &&
                <LoadingSpinner style={{ marginLeft: 'auto', marginRight: 'auto' }} color={theme.colors.primary}/>
            }

            {!loading && 
                <>{text}</>
            }
        </button>
        </>
    );
}

export default Button;