import React, { FunctionComponent } from 'react';

import theme from '../../styles/theme';

type IInputProp = {
    name: string;
    description: string;

    type?: string;
    style?: React.CSSProperties;
    error?: string;
    value?: string;
    
    onValueChange: (name: string, value: string) => void;
}

const Input: FunctionComponent<IInputProp> = ({ name, description, type, style, error, value, onValueChange }) => {
    return (
        <>
        <style jsx>{`
            .input-label {
                padding: 0;
                margin: 0;
                font-size: ${theme.fontSizes.medium}px;
                color: ${error ? theme.colors.error : theme.colors.secondary};
                text-align: start;
            }

            .input-error-label {
                display: ${error ? 'block' : 'none'};
                padding: 0;
                margin: 0;
                font-size: ${theme.fontSizes.small}px;
                color: ${theme.colors.error};
                text-align: start;
            }

            .input {
                background-color: transparent;
                border: none;
                outline: none;
                width: 100%;
                height: 50px;
                padding: 0;
                margin: 0;
                padding-left: 10px;
                padding-right: 10px;
                text-overflow: ellipsis;
                white-space: nowrap;
                font-family: "Poppins", sans-serif;
                font-size: ${theme.fontSizes.medium}px;
                font-weight: 500;
            }

            .input-container {
                display: flex;
                align-items: stretch;
                border: 1px solid ${error ? theme.colors.error : theme.colors.secondary};
                border-radius: 5px;
                padding: 0;
                margin: 0;
                margin-top: 5px;
            }
        `}</style>

        <div style={style}>
            <p className="input-label">{description}</p>
            
            <div className="input-container">
                <input className="input" name={name} value={value} type={type} onChange={ (e) => onValueChange(name, e.target.value) }/>
            </div>

            <p className="input-error-label">{error}</p>
        </div>
        </>
    );
}

export default Input;