import React, { FunctionComponent } from 'react';

import theme from '../../styles/theme';


export type ISelectOptionType = {
    text: string;
    value: any;
}

type ISelectProp = {
    name: string;
    description: string;
    options: ISelectOptionType[];

    style?: React.CSSProperties;
    error?: string;
    value?: string;

    onValueChange: (name: string, value: string) => void;
}

const Select: FunctionComponent<ISelectProp> = ({ name, description, options, style, error, value, onValueChange }) => {
    return (
        <>
        <style jsx>{`
            .input-label {
                padding: 0;
                margin: 0;
                font-size: ${theme.fontSizes.medium}px;
                color: ${error ? theme.colors.error : theme.colors.secondary};
                text-align: start;
            }

            .input-error-label {
                display: ${error ? 'block' : 'none'};
                padding: 0;
                margin: 0;
                font-size: ${theme.fontSizes.small}px;
                color: ${theme.colors.error};
                text-align: start;
            }

            .input-container {
                display: flex;
                align-items: stretch;
                border: 1px solid ${error ? theme.colors.error : theme.colors.secondary};
                border-radius: 5px;
                padding: 0;
                margin: 0;
                margin-top: 5px;
            }

            .input {
                background-color: transparent;
                border: none;
                outline: none;
                width: 100%;
                height: 50px;
                padding: 0;
                margin: 0;
                padding-left: 10px;
                padding-right: 10px;
                text-overflow: ellipsis;
                white-space: nowrap;
                font-family: "Poppins", sans-serif;
                font-size: ${theme.fontSizes.medium}px;
                font-weight: 500;
            }
        `}</style>

        <div style={style}>
            <p className="input-label">{description}</p>

            <div className="input-container">
                <select className="input" style={{ marginLeft: '-4px' }} name={name} value={value} onChange={(event: React.ChangeEvent<HTMLSelectElement>) => onValueChange(name, event.target.value)}>
                    {options.map((value, index) => {
                        return <option key={value.value} value={value.value}>{value.text}</option>
                    })}
                </select>
            </div>

            <p className="input-error-label">{error}</p>
        </div>
        </>
    )
}

export default Select;