import React, { FunctionComponent } from 'react';

import DropdownButtonMenuItem from './DropdownButtonMenuItem';

import theme from '../../../styles/theme';


type IDropdownButtonProp = {
    label: string;
    menuItems: IDropdownMenuItemType[];
    style?: React.CSSProperties;
}

export type IDropdownMenuItemType = {
    text: string;
    textColor?: string;
    backgroundColor?: string;
    onClick: (event: React.MouseEvent) => void;
}

const DropdownButton: FunctionComponent<IDropdownButtonProp> = ({ label, menuItems, style }) => {
    return (
        <>
        <style jsx>{`
            .dropdown-button {
                padding: 0;
                margin: 0;
                border: none;
                border-radius: 5px;
                outline: none;
                width: 100%;
                height: 50px;
                font-family: "Poppins", sans-serif;
                font-size: ${theme.fontSizes.button}px;
                color: ${theme.colors.primary};
                background-color: ${theme.colors.secondary};
                cursor: pointer;
            }

            .dropdown-button-menu {
                position: absolute;
                display: none;
                border: 1px solid #ccc;
                border-radius: 4px;
                padding: 0;
                margin: 2px 0 0 0;
                box-shadow: 0 0 6px 0 rgba(0,0,0,0.1);
                background-color: #ffffff;
                list-style-type: none;
            }

            .dropdown:hover .dropdown-button-menu {
                display: block;
            }
        `}</style>

        <div className="dropdown" style={style}>
            <button className="dropdown-button" onClick={(event) => event.preventDefault()}>
                {label}
            </button>

            <ul className="dropdown-button-menu">
                {
                menuItems.map((item, index) => {
                    return (<DropdownButtonMenuItem key={index} text={item.text} onClick={item.onClick} textColor={item.textColor} backgroundColor={item.backgroundColor}/>)
                })
                }
            </ul>
        </div>
        </>
    );
}

export default DropdownButton;