import React, { FunctionComponent, useState, useEffect } from 'react';

import theme from '../../styles/theme';

import core from '@felixbaum/me.easymove.core';
import { UITab } from '@felixbaum/me.easymove.common/dist/enums/ui';


type INavbarLinkProp = {
    href: string;
    activePage: UITab;
    style?: React.CSSProperties;
}

const NavbarLink: FunctionComponent<INavbarLinkProp> = ({ href, activePage, style, children }) => {
    const [active, setActive] = useState<boolean>(false);

    useEffect(() => {
        if (activePage === core.ui.state.CURRENT_TAB.value) setActive(true);
        else setActive(false);
    }, [core.ui.state.CURRENT_TAB]);

    return (
        <>
        <style jsx>{`
            .navbar-link {
                display: flex;
                color: black;
                font-weight: 500;
                text-decoration: none;
                align-items: center;
                font-size: ${theme.fontSizes.small}px;
            }

            .navbar-link.active {
                color: ${theme.colors.primary};
            }

            .navbar-link:hover {
                color: ${theme.colors.secondary};
            }
        `}</style>

        <a className={`navbar-link ${active ? 'active' : ''}`} style={style} href={href}>
            {children}
        </a>
        </>
    );
}

export default NavbarLink;