import React, { useState, useEffect } from 'react';
import { GetServerSideProps } from 'next';
import { useRouter } from 'next/router';
import { useToasts } from 'react-toast-notifications';

import { LayoutFuntionComponent } from '../../_app';
import { protectedByLogin } from '../../../utils/protection';

import { SiteWidthContainer } from '../../../components/containers';
import { MenuBackButton } from '../../../components/menu';
import { AddressDialog } from '../../../components/dialogs';
import UserLayout from '../../../components/layouts/UserLayout';

import core from '@felixbaum/me.easymove.core';
import { IAddress } from '@felixbaum/me.easymove.common/dist/interfaces/addresses';
import { UITab } from '@felixbaum/me.easymove.common/dist/enums/ui';


const Address: LayoutFuntionComponent = () => {
    const [address, setAddress] = useState<IAddress>({ addressId: -1, description: '', changedOn: new Date(), payload: { salutation: '', title: '', firstname: '', lastname: '', zip: '', city: '', street: '', houseno: '', info: '' } });
    const [addressLoading, setAddressLoading] = useState(true);
    const [saveLoading, setSaveLoading] = useState(false);
    const router = useRouter();
    const { addToast } = useToasts();
    const { id } = router.query;


    if (!id || id === '') router.push('/user/addresses');

    core.ui.state.CURRENT_TAB.set(UITab.USER_ADDRESSES);

    useEffect(() => {
        core.address.actions.getAddress(+id).then(result => {
            if (result.code === 404) router.push('/user/addresses');
            setAddress(result.result);
            setAddressLoading(false);
        }).catch(error => {
            console.log(error);
            addToast('Ups! Da ist etwas schief gelaufen!', {
                appearance: 'error',
                autoDismiss: true
            });
            setAddressLoading(false);
        });
    }, []);

    const onBackButtonClick = () => {
        router.back();
    }

    const onSave = (address: IAddress) => {
        setSaveLoading(true);
        setAddress(address);

        core.address.actions.updateAddress(address.addressId, address.description, address.payload).then(result => {
            setSaveLoading(false);

            addToast('Adresse erfolgreich gespeichert!', {
                appearance: 'success',
                autoDismiss: true
            });
            
            router.push('/user/addresses');
        }).catch(error => {
            console.log(error);
        });
    }


    return (
        <SiteWidthContainer>
            <MenuBackButton text="Zurück" textColor="white" onBackButtonClick={onBackButtonClick}/>

            <AddressDialog style={{ marginTop: '50px' }} isNew={false} saveLoading={saveLoading} addressLoading={addressLoading} currentAddress={address} onSave={onSave}/>
        </SiteWidthContainer>
    );
}

Address.Layout = UserLayout;
export const getServerSideProps: GetServerSideProps = protectedByLogin;
export default Address;