import React, { useState } from 'react';
import { GetServerSideProps } from 'next';
import { useRouter } from 'next/router';
import { useToasts } from 'react-toast-notifications';

import { protectedByLogin } from '../../../utils/protection';
import { LayoutFuntionComponent } from '../../_app';

import { SiteWidthContainer } from '../../../components/containers';
import { MenuBackButton } from '../../../components/menu';
import { AddressDialog } from '../../../components/dialogs';
import UserLayout from '../../../components/layouts/UserLayout';

import core from '@felixbaum/me.easymove.core';
import { IAddress } from '@felixbaum/me.easymove.common/dist/interfaces/addresses';
import { UITab } from '@felixbaum/me.easymove.common/dist/enums/ui';


const NewAddress: LayoutFuntionComponent = () => {
    const [address, setAddress] = useState<IAddress>({ addressId: -1, description: '', changedOn: new Date(), payload: { salutation: '', title: '', firstname: '', lastname: '', zip: '', city: '', street: '', houseno: '', info: '' } });
    const [loading, setLoading] = useState(false);
    const router = useRouter();
    const { addToast } = useToasts();


    core.ui.state.CURRENT_TAB.set(UITab.USER_ADDRESSES);

    const onBackButtonClick = () => {
        router.back();
    }

    const onSave = (address: IAddress) => {
        setLoading(true);
        setAddress(address);

        core.address.actions.createAddress(address.description, address.payload).then(result => {
            setLoading(false);

            addToast('Adresse erfolgreich gespeichert!', {
                appearance: 'success',
                autoDismiss: true
            });
            
            router.push('/user/addresses');
        }).catch(error => {
            console.log(error);
        });
    }

    return (
        <SiteWidthContainer>
            <MenuBackButton text="Zurück" textColor="white" onBackButtonClick={onBackButtonClick}/>

            <AddressDialog style={{ marginTop: '50px' }} isNew={true} saveLoading={loading} currentAddress={address} onSave={onSave}/>
        </SiteWidthContainer>
    )
}


NewAddress.Layout = UserLayout;
export const getServerSideProps: GetServerSideProps = protectedByLogin;
export default NewAddress;