import React, { FunctionComponent, useState } from 'react';
import { GetServerSideProps } from 'next';

import { alreadyLoggedIn } from '../../utils/protection';

import { FullPageContainer, CenteringContainer, Card } from '../../components/containers';
import { Heading, Link, Paragraph } from '../../components/text';
import { Input, Button } from '../../components/input';

import theme from '../../styles/theme';

const Reset: FunctionComponent = () => {
    const [email, setEmail] = useState("");

    const onSubmit = (event: React.MouseEvent) => {
        event.preventDefault();
    }

    return (
        <FullPageContainer background={theme.colors.gradientBackground}>
            <CenteringContainer>
                <Card style={{ width: '700px' }}>
                    <Heading fontSize={theme.fontSizes.fat} fontColor={theme.colors.primary}>EasyMove</Heading>

                    <Paragraph style={{ width: '80%', marginTop: '50px' }}>Gib deine E-Mail-Adresse ein, mit der du dich bei uns registriert hast und wir senden dir einen Link zum Zurücksetzen deines Passwortes zu.</Paragraph>

                    <form noValidate style={{ width: '80%', marginTop: '50px' }}>
                        <Input name="email" description="E-Mail-Adresse" type="email" onValueChange={ (name, value) => setEmail(value) }/>

                        <Button style={{ marginTop: '50px' }} type="submit" text="Senden" onClick={onSubmit}/>
                    </form>
                </Card>

                <p style={{ color: 'white', margin: 0, marginTop: '5px' }}>Du hast schon ein Konto? <Link color="black" href="/user/login">Anmelden.</Link> </p>
            </CenteringContainer>
        </FullPageContainer>
    );
}

export const getServerSideProps: GetServerSideProps = alreadyLoggedIn;

export default Reset;