import React, { FunctionComponent, useState, useEffect } from 'react';
import { GetServerSideProps } from 'next';
import { useRouter } from 'next/router';

import { alreadyLoggedIn } from '../../utils/protection';

import { FullPageContainer, CenteringContainer, Card, LoadingSpinner } from '../../components/containers';
import { Heading, Link, Paragraph } from '../../components/text';

import theme from '../../styles/theme';
import core from '@felixbaum/me.easymove.core';


const Verify: FunctionComponent = () => {
    const [loading, setLoading] = useState(true);

    const router = useRouter();
    const id = +router.query.id;
    const code = router.query.code !== undefined ? router.query.code.toString() : '';

    useEffect(() => {
        core.authentication.actions.verify(id, code).then((result) => {
            if (result.code === 200) {
            }

            setLoading(false);
        }).catch((error) => {
            console.log(error);
            setLoading(false);
        });
    });

    return (
        <>

        <FullPageContainer background={theme.colors.gradientBackground}>
            <CenteringContainer>
                {loading && 
                <LoadingSpinner/>
                }

                {!loading &&
                
                <Card style={{ width: '700px' }}>
                    <Heading fontSize={theme.fontSizes.fat} fontColor={theme.colors.primary}>EasyMove</Heading>

                    <Paragraph style={{ marginTop: '50px' }}>
                        Du hast deinen Account erfolgreich aktiviert und kannst dich nun anmelden.
                    </Paragraph>

                    <Link style={{ marginTop: '50px' }} color="black" href="/user/login">Jetzt anmelden</Link>
                </Card>

                }
            </CenteringContainer>
        </FullPageContainer>

        </>
    )
}

export const getServerSideProps: GetServerSideProps = alreadyLoggedIn;

export default Verify;