function isNotEmpty(value: any, name: string, errorFunc: (message: string) => void): boolean {
    if (value === undefined || value === null || value === '') {
        errorFunc(`${name} ist erforderlich`);
        return false;
    }

    return true;
}

function isValidEmail(value: string, errorFunc: (message: string) => void): boolean {
    const regex = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    if (regex.exec(value) === null) {
        errorFunc('Ungültige E-Mail-Adresse');
        return false;
    }

    return true;
}

function isValidPassword(value: string, errorFunc: (message: string) => void): boolean {
    const strongRegex = /(?=.*\d)(?=.*[A-Z])(?=.*[a-z])(?=.+[\.\,\/\#\!\$\%\^\&\*\;\:\=\-\_]).*/g;
    const enoughRegex = /(?=.{8,}).*/g;

    const enoughResult = enoughRegex.exec(value);
    if (enoughResult === null) {
        errorFunc('Passwort muss aus min. 8 Zeichen bestehen');
        return false;
    } else {
        const strongResult = strongRegex.exec(value);

        if (strongResult === null) {
            errorFunc('Passwort muss min. ein Sonderzeichen und eine Zahl enthalten');
            return false;
        } else {
            return true;
        }
    }
}


export {
    isNotEmpty,
    isValidEmail,
    isValidPassword
}